@@ -18,11 +18,16 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from pyCore.utils import request
-from task import Task
-from pyCore.models.base_model import BaseModel
+from pyCore.models.template import Template
+from pyCore.models.image import Image
 
 
 class VM(BaseModel):
+    def __init__(self, *args, **kwargs):
+        super(VM, self).__init__(*args, **kwargs)
+        self.template = Template(self.oc_address, self.token, self.template)
+        self.base_image = Image(self.oc_address, self.token, self.base_image)
+
     def __str__(self):
         return self.name
         
